OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Не можу писати у каталог \"config\"!",
    "This can usually be fixed by giving the web server write access to the config directory." : "Зазвичай це можна виправити, надавши веб-серверу доступ для запису до каталогу конфігурації.",
    "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "Але якщо ви віддаєте перевагу файлу config.php лише для читання, встановіть для параметра \"config_is_read_only\" значення true.",
    "See %s" : "Переглянути %s",
    "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "Застосунок %1$s відсутній або має несумісну з цим сервером версію. Будь ласка, перевірте каталог додатків.",
    "Sample configuration detected" : "Виявлено приклад конфігурації",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Було виявлено, що приклад конфігурації було скопійовано. Це може нашкодити вашій системі та не підтримується. Будь ласка, зверніться до документації перед внесенням змін в файл config.php",
    "The page could not be found on the server." : "Сторінку не знайдено на сервері.",
    "%s email verification" : "%s підтвердження електронної пошти",
    "Email verification" : "Підтвердження електронної пошти",
    "Click the following button to confirm your email." : "Натисніть наступну кнопку, щоб підтвердити свою електронну адресу.",
    "Click the following link to confirm your email." : "Натисніть це посилання, щоб підтвердити свою електронну адресу.",
    "Confirm your email" : "Підтвердьте свою електронну адресу",
    "Other activities" : "Інша активність",
    "%1$s and %2$s" : "%1$s та %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s та %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s та %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s та %5$s",
    "Education Edition" : "Для навчання",
    "Enterprise bundle" : "Для бізнесу",
    "Groupware bundle" : "Для робочих груп",
    "Hub bundle" : "Основні застосунки",
    "Social sharing bundle" : "Для соціальних мереж",
    "PHP %s or higher is required." : "Необхідно PHP %s або вище",
    "PHP with a version lower than %s is required." : "Потрібна версія PHP нижче %s ",
    "%sbit or higher PHP required." : "%sнеобхідний PHP біт або вище.",
    "The following architectures are supported: %s" : "Підтримуються такі архітектури: %s",
    "The following databases are supported: %s" : "Підтримуються такі бази даних: %s",
    "The command line tool %s could not be found" : "Утиліту командного рядка %s не знайдено",
    "The library %s is not available." : "Бібліотека %s недоступна.",
    "Library %1$s with a version higher than %2$s is required - available version %3$s." : "Бібліотека %1$s з версією вищою за необхідну %2$s - доступна версія %3$s.",
    "Library %1$s with a version lower than %2$s is required - available version %3$s." : "Бібліотека %1$s з версією нижчою за необхідну %2$s - доступна версія %3$s.",
    "The following platforms are supported: %s" : "Підтримуються такі платформи: %s",
    "Server version %s or higher is required." : "Потрібна версія сервера %s або вище.",
    "Server version %s or lower is required." : "Потрібна версія сервера %s або нижча.",
    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Обліковий запис для входу має бути адміністратором, заступником адміністратора або мати спеціальні права доступу до цих налаштувань.",
    "Logged in account must be an admin or sub admin" : "Обліковий запис для входу має бути адміністратором, заступником адміністратора",
    "Logged in account must be an admin" : "Обліковий запис для входу має бути адміністратором",
    "Wiping of device %s has started" : "Розпочато очищення пристрою %s",
    "Wiping of device »%s« has started" : "Розпочато стирання даних на пристрої \"%s\".",
    "»%s« started remote wipe" : "\"%s\" розпочато віддалене стирання даних",
    "Device or application »%s« has started the remote wipe process. You will receive another email once the process has finished" : "Пристрій або застосунок \"%s\" розпочали процес віддаленого стирання даних. Після завершення процесу ви отримаєте відповідне сповіщення електронною поштою.",
    "Wiping of device %s has finished" : "Очищення пристрою %s завершено",
    "Wiping of device »%s« has finished" : "Стирання даних на пристрої \"%s\" завершено",
    "»%s« finished remote wipe" : "\"%s\" віддалене очищення стирання даних",
    "Device or application »%s« has finished the remote wipe process." : "Пристрій або застосунок \"%s\" завершили процес віддаленого стирання даних.",
    "Remote wipe started" : "Розпочато віддалене стирання",
    "A remote wipe was started on device %s" : "На пристрої %s розпочато віддалене стирання",
    "Remote wipe finished" : "Віддалене стирання завершено",
    "The remote wipe on %s has finished" : "Дистанційне стирання на %s завершено",
    "Authentication" : "Авторизація",
    "Unknown filetype" : "Невідомий тип файлу",
    "Invalid image" : "Недійсне зображення",
    "Avatar image is not square" : "Зображення аватара не квадратне",
    "Files" : "Файли",
    "View profile" : "Перегляд профілю",
    "Local time: %s" : "Місцевий час: %s",
    "today" : "сьогодні",
    "tomorrow" : "завтра",
    "yesterday" : "вчора",
    "_in %n day_::_in %n days_" : ["через %n день","через %n дні","через %n днів","через %n днів"],
    "_%n day ago_::_%n days ago_" : ["%n день тому","%n днів тому","%n днів тому","%n днів тому"],
    "next month" : "наступноого місяця",
    "last month" : "минулого місяця",
    "_in %n month_::_in %n months_" : ["в %n місяць","в %n місяцях","в %n місяцях","в %n місяцях"],
    "_%n month ago_::_%n months ago_" : ["%n місяць тому","%n місяць тому","%n місяців тому","%n місяців тому"],
    "next year" : "наступного року",
    "last year" : "минулого року",
    "_in %n year_::_in %n years_" : ["в %n рік","в %n роках","в %n роках","в %n роках"],
    "_%n year ago_::_%n years ago_" : ["%n рік тому","%n років тому","%n років тому","%n років тому"],
    "_in %n hour_::_in %n hours_" : ["в %n годин","в %n годинах","в %n годинах","в %n годинах"],
    "_%n hour ago_::_%n hours ago_" : ["%nгодину тому","%n годин тому","%n годин тому","%n годин тому"],
    "_in %n minute_::_in %n minutes_" : ["за %n хвилину","за %n хвилин","за %n хвилин","за %n хвилин"],
    "_%n minute ago_::_%n minutes ago_" : ["%n хвилину тому","%n хвилин тому","%n хвилин тому","%n хвилин тому"],
    "in a few seconds" : "через кілька секунд",
    "seconds ago" : "кілька секунд тому",
    "Empty file" : "Порожній файл",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Модуль з ID: %s не існує. Будь ласка, увімкніть це в налаштуваннях застосунку або зверніться до адміністратора.",
    "File already exists" : "Файл вже існує",
    "Invalid path" : "Недійсний шлях",
    "Failed to create file from template" : "Не вдалося створити файл із шаблону",
    "Templates" : "Шаблони",
    "File name is a reserved word" : "Ім’я файлу є зарезервованим словом",
    "File name contains at least one invalid character" : "Ім’я файлу містить принаймні один некоректний символ",
    "File name is too long" : "Ім’я файлу занадто довге",
    "Dot files are not allowed" : "Файли які починаються з крапки не допустимі",
    "Empty filename is not allowed" : "Порожні імена файлів не допускаються",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "Застосунок \"%s\" не може бути встановлений через те, що файл appinfo не може бути прочитано.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Застосунок \"%s\" неможливо встановити, оскільки він не сумісний з цією версією сервера.",
    "__language_name__" : "Українська",
    "This is an automatically sent email, please do not reply." : "Це автоматично надісланий електронний лист, будь ласка, не відповідайте на нього.",
    "Help" : "Допомога",
    "Appearance and accessibility" : "Тема та вигляд",
    "Apps" : "Застосунки",
    "Personal settings" : "Мої налаштування",
    "Administration settings" : "Адміністрування",
    "Settings" : "Налаштування",
    "Log out" : "Вихід",
    "Users" : "Користувачі",
    "Email" : "Електронна пошта",
    "Mail %s" : "Пошта %s",
    "Fediverse" : "Fediverse",
    "View %s on the fediverse" : "Переглянути %s у Fediverse",
    "Phone" : "Телефон",
    "Call %s" : "Телефонуйте %s",
    "Twitter" : "Twitter",
    "View %s on Twitter" : "Переглянути %s в Twitter",
    "Website" : "Вебсайт",
    "Visit %s" : "Відвідайте %s",
    "Address" : "Адреса",
    "Profile picture" : "Зображення облікового запису",
    "About" : "Опис",
    "Display name" : "Ім'я для показу",
    "Headline" : "Заголовок",
    "Organisation" : "Організація",
    "Role" : "Роль",
    "Unknown account" : "Невідомий обліковий запис",
    "Additional settings" : "Додатково",
    "Enter the database Login and name for %s" : "Введіть ім’я користувача та назву бази даних для %s",
    "Enter the database Login for %s" : "Введіть ім'я користувача бази даних для %s",
    "Enter the database name for %s" : "Введіть назву бази даних для %s",
    "You cannot use dots in the database name %s" : "Не можна використовувати крапки в назві бази даних %s",
    "MySQL Login and/or password not valid" : "Ім'я користувача та/або пароль MySQL недійсні",
    "You need to enter details of an existing account." : "Потрібно ввести дані наявного облікового запису.",
    "Oracle connection could not be established" : "Не можемо з'єднатися з Oracle ",
    "Oracle Login and/or password not valid" : "Ім'я користувача та/або пароль Oracle не дійсні",
    "PostgreSQL Login and/or password not valid" : "Ім'я користувача та/або пароль PostgreSQL не дійсні",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X не підтримується і %s не буде коректно працювати на цій платформі. Випробовуєте на свій риск!",
    "For the best results, please consider using a GNU/Linux server instead." : "Для кращих результатів розгляньте можливість використання GNU/Linux серверу",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Ймовірно, що сервер %s працює в 32-бітному PHP середовищі і open_basedir повинен бути налаштований в php.ini. Це призведе до проблем з файлами більше 4 ГБ і це дуже не рекомендується.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Будь ласка, вилучіть параметр open_basedir у вашому php.ini або перейдіть на 64-бітний PHP.",
    "Set an admin Login." : "Встановіть ім'я облікового запису адміністратора.",
    "Set an admin password." : "Встановіть пароль адміністратора.",
    "Cannot create or write into the data directory %s" : "Неможливо створити або записати в каталог даних %s",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Бекенд спільного доступу %s повинен реалізовувати інтерфейс OCP\\Share_Backend",
    "Sharing backend %s not found" : "Бекенд спільного доступу %s не знайдено",
    "Sharing backend for %s not found" : "Бекенд спільного доступу для %s не знайдено",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s надав(-ла) доступ до \"%2$s\" та хоче додати:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s надав(-ла) доступ до \"%2$s\" та хоче додати",
    "»%s« added a note to a file shared with you" : "\"%s\" додано примітку до файлу у спільному доступі",
    "Open »%s«" : "Відкрити %s",
    "%1$s via %2$s" : "%1$s через %2$s",
    "You are not allowed to share %s" : "Вам заборонено поширювати %s",
    "Cannot increase permissions of %s" : "Не вдалося підвищити дозволи для %s",
    "Files cannot be shared with delete permissions" : "Не можна ділитися файлами з дозволом на видалення",
    "Files cannot be shared with create permissions" : "Не можна ділитися файлами з дозволом на створення",
    "Expiration date is in the past" : "Дата закінчення в минулому",
    "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Неможливо встановити дату закінчення більше ніж %n день у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому","Неможливо встановити дату закінчення більше ніж %n днів у майбутньому"],
    "Sharing is only allowed with group members" : "Спільний доступ дозволений лише для учасників групи",
    "Sharing %s failed, because this item is already shared with the account %s" : "Не вдалося надати у спільний доступ%s, оскільки цей ресурс вже у спільному доступі з обліковим записом %s",
    "%1$s shared »%2$s« with you" : "%1$s надав(-ла) доступ до \"%2$s\"",
    "%1$s shared »%2$s« with you." : "%1$s надав(-ла) доступ до \"%2$s\".",
    "Click the button below to open it." : "Щоб відкрити файл, натисніть кнопку нижче.",
    "The requested share does not exist anymore" : "Запитуваний спільний ресурс більше недоступний",
    "The requested share comes from a disabled user" : "Отримано запит на спільний доступ від неактивного користувача",
    "The user was not created because the user limit has been reached. Check your notifications to learn more." : "Користувача не створено, оскільки досягнуто обмеження на кількість користувачів. Перевірте сповіщення для докладної інформації.",
    "Could not find category \"%s\"" : "Не вдалося знайти категорію \"%s\"",
    "Sunday" : "Неділя",
    "Monday" : "Понеділок",
    "Tuesday" : "Вівторок",
    "Wednesday" : "Середа",
    "Thursday" : "Четвер",
    "Friday" : "П'ятниця",
    "Saturday" : "Субота",
    "Sun." : "Нд.",
    "Mon." : "Пн.",
    "Tue." : "Вт.",
    "Wed." : "Ср.",
    "Thu." : "Чт.",
    "Fri." : "Пт.",
    "Sat." : "Сб.",
    "Su" : "Нд.",
    "Mo" : "Пн.",
    "Tu" : "Вт.",
    "We" : "Ср.",
    "Th" : "Чт.",
    "Fr" : "Пт.",
    "Sa" : "Сб.",
    "January" : "Січень",
    "February" : "Лютий",
    "March" : "Березень",
    "April" : "Квітень",
    "May" : "Травень",
    "June" : "Червень",
    "July" : "Липень",
    "August" : "Серпень",
    "September" : "Вересень",
    "October" : "Жовтень",
    "November" : "Листопад",
    "December" : "Грудень",
    "Jan." : "Січ.",
    "Feb." : "Лют.",
    "Mar." : "Бер.",
    "Apr." : "Кві.",
    "May." : "Тра.",
    "Jun." : "Чер.",
    "Jul." : "Лип.",
    "Aug." : "Сер.",
    "Sep." : "Вер.",
    "Oct." : "Жов.",
    "Nov." : "Лис.",
    "Dec." : "Гру.",
    "A valid password must be provided" : "Потрібно задати вірний пароль",
    "The Login is already being used" : "Це ім'я облікового запису вже використовується",
    "Could not create account" : "Не вдалося створити обліковий запис",
    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Лише такі символи дозволено у імені облікового запису: \"a-z\", \"A-Z\", \"0-9\", пробіл та \"_.@-'\"",
    "A valid Login must be provided" : "Зазначте дійсне ім'я користувача",
    "Login contains whitespace at the beginning or at the end" : "Ім'я користувача містить символ пробілу на початку або наприкінці",
    "Login must not consist of dots only" : "Ім'я користувача не може складатися лише з крапок",
    "Login is invalid because files already exist for this user" : "Недійсне ім'я облікового запису, оскільки файли для цього користувача вже присутні",
    "Account disabled" : "Обліковий запис вимкнено",
    "Login canceled by app" : "Вхід скасовано застосунком",
    "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Застосунок \"%1$s\" неможливо встановити, оскільки не виконано такі залежності: %2$s",
    "a safe home for all your data" : "безпечний дім для ваших даних",
    "File is currently busy, please try again later" : "Файл на разі зайнятий, будь ласка, спробуйте пізніше",
    "Cannot download file" : "Неможливо завантажити файл",
    "Application is not enabled" : "Застосунок не увімкнено",
    "Authentication error" : "Помилка авторизації",
    "Token expired. Please reload page." : "Строк дії токена скінчився. Будь ласка, перезавантажте сторінку.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "Не встановлено драйвер бази даних (sqlite, mysql, or postgresql).",
    "Cannot write into \"config\" directory." : "Не вдається записати в каталог \"config\".",
    "This can usually be fixed by giving the web server write access to the config directory. See %s" : "Зазвичай це можна виправити, надавши веб-серверу доступ для запису до каталогу конфігурації. Побачити %s",
    "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "Або, якщо ви віддаєте перевагу файлу config.php лише для читання, встановіть для параметра \"config_is_read_only\" значення true. Побачити %s",
    "Cannot write into \"apps\" directory." : "Відсутній доступ на запис до каталогу застосунків \"apps\".",
    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "Зазвичай це можна виправити, якщо надати вебсерверу доступ для запису до каталогу застосунків або вимкнути App Store у конфігураційному файлі.",
    "Cannot create \"data\" directory." : "Неможливо створити каталог \"data\".",
    "This can usually be fixed by giving the web server write access to the root directory. See %s" : "Зазвичай це можна виправити, надавши веб-серверу доступ на запис до кореневого каталогу. Побачити %s",
    "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "Дозволи зазвичай можна виправити, надавши веб-серверу доступ на запис до кореневого каталогу. Побачити %s. ",
    "Your data directory is not writable." : "Ваш каталог даних не доступний для запису.",
    "Setting locale to %s failed." : "Помилка налаштування мови %s.",
    "Please install one of these locales on your system and restart your web server." : "Установіть одну з цих локалей у вашій системі та перезапустіть веб-сервер.",
    "PHP module %s not installed." : "%s модуль PHP не встановлено.",
    "Please ask your server administrator to install the module." : "Будь ласка, зверніться до адміністратора, щоб встановити модуль.",
    "PHP setting \"%s\" is not set to \"%s\"." : "Параметр PHP \"%s\" не встановлено в \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Налаштування цього параметра у php.ini змусить Nextcloud запуститися знову",
    "<code>mbstring.func_overload</code> is set to <code>%s</code> instead of the expected value <code>0</code>." : "<code>mbstring.func_overload</code> замість <code>%s</code> очікуваного значення <code>0</code>.",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini." : "Щоб вирішити цю проблему, установіть для <code>mbstring.func_overload</code> значення <code>0</code> у вашому php.ini.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "Схоже, що PHP налаштовано на обрізання блоків вбудованих документів. Це зробить кілька головних застосунків недоступними.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Це, ймовірно, обумовлено використанням кеша/прискорювача такого як Zend OPcache або eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "Модулі PHP були встановлені, але вони все ще перераховані як відсутні?",
    "Please ask your server administrator to restart the web server." : "Будь ласка, зверніться до адміністратора, щоб перезавантажити сервер.",
    "The required %s config variable is not configured in the config.php file." : "Необхідна змінна конфігурації %s не налаштована у файлі config.php.",
    "Please ask your server administrator to check the Nextcloud configuration." : "Будь ласка, попросіть свого адміністратора сервера перевірити конфігурацію Nextcloud.",
    "Your data directory is readable by other people." : "Ваш каталог даних доступний для читання для інших користувачів.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу.",
    "Your data directory must be an absolute path." : "Ваш каталог даних має бути абсолютним шляхом.",
    "Check the value of \"datadirectory\" in your configuration." : "Перевірте значення «каталогу даних» у вашій конфігурації.",
    "Your data directory is invalid." : "Ваш каталог даних недійсний.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Переконайтеся, що в корені каталогу даних є файл під назвою \".ocdata\".",
    "Action \"%s\" not supported or implemented." : "Дія \"%s\" не підтримується або не реалізована.",
    "Authentication failed, wrong token or provider ID given" : "Помилка авторизації, надано неправильний маркер або ідентифікатор постачальника",
    "Parameters missing in order to complete the request. Missing Parameters: \"%s\"" : "Немає параметрів для виконання запиту. Відсутні параметри: \"%s\"",
    "ID \"%1$s\" already used by cloud federation provider \"%2$s\"" : "Ідентифікатор \"%1$s\" уже використовується постачальником об'єднаних хмар \"%2$s\"",
    "Cloud Federation Provider with ID: \"%s\" does not exist." : "Постачальник Cloud Federation з ідентифікатором \"%s\" не існує.",
    "Could not obtain lock type %d on \"%s\"." : "Не вдалося отримати блокування типу %d для \"%s\"",
    "Storage unauthorized. %s" : "Сховище не авторизовано. %s",
    "Storage incomplete configuration. %s" : "Неповна конфігурація сховища. %s",
    "Storage connection error. %s" : "Помилка з'єднання зі сховищем. %s",
    "Storage is temporarily not available" : "Сховище тимчасово недоступне",
    "Storage connection timeout. %s" : "Час під'єднання до сховища вичерпався. %s",
    "Free prompt" : "Вільне запрошення",
    "Runs an arbitrary prompt through the language model." : "Виконує довільне запрошення через мовну модель.",
    "Generate headline" : "Створити заголовок",
    "Generates a possible headline for a text." : "Створює ймовірний заголовок тексту.",
    "Summarize" : "Підсумок",
    "Summarizes text by reducing its length without losing key information." : "Викокремлює головне у тексті шляхом зменшення довжини тексту без втрати ключової інформації.",
    "Extract topics" : "Виділити теми",
    "Extracts topics from a text and outputs them separated by commas." : "Виділяє теми, які висвітлює текст, зводить їх у перелік, що розділено комами.",
    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Файли застосунку %1$s не було коректно оновлено. Переконайтеся, що ця версія, сумісна із сервером.",
    "404" : "404",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Користувач, який увійшов у систему, має бути адміністратором, підадміністратором або мати спеціальні права доступу до цього налаштування",
    "Logged in user must be an admin or sub admin" : "Увійшовши в систему користувач повинен бути адміністратором або підадміністратором",
    "Logged in user must be an admin" : "Зареєстрований користувач має бути адміністратором",
    "Full name" : "Повна назва",
    "Unknown user" : "Невідомий користувач",
    "Enter the database username and name for %s" : "Введіть ім’я користувача та назву бази даних %s",
    "Enter the database username for %s" : "Введіть ім’я користувача бази даних для %s",
    "MySQL username and/or password not valid" : "Ім'я користувача та/або пароль MySQL недійсні",
    "Oracle username and/or password not valid" : "Oracle ім'я користувача та/або пароль не дійсні",
    "PostgreSQL username and/or password not valid" : "PostgreSQL ім'я користувача та/або пароль не дійсні",
    "Set an admin username." : "Встановіть ім'я адміністратора.",
    "Sharing %s failed, because this item is already shared with user %s" : "Не вдалося поділитися %s, оскільки %s вже має до нього доступ",
    "The username is already being used" : "Ім'я користувача вже використовується",
    "Could not create user" : "Не вдалося створити користувача",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Лише такі символи дозволено у імені користувача: \"a-z\", \"A-Z\", \"0-9\", пробіл та \"_.@-'\"",
    "A valid username must be provided" : "Потрібно задати вірне ім'я користувача",
    "Username contains whitespace at the beginning or at the end" : "Ім'я користувача містить символ пробілу в початку або в кінці",
    "Username must not consist of dots only" : "Ім'я користувача не повинно складатися лише з крапок",
    "Username is invalid because files already exist for this user" : "Ім'я користувача недійсне, оскільки файли для цього користувача вже існують",
    "User disabled" : "Користувач виключений",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Необхідно libxml2 версії принаймні 2.7.0. На разі встановлена %s.",
    "To fix this issue update your libxml2 version and restart your web server." : "Що виправити це оновіть версію libxml2 та перезапустіть веб-сервер.",
    "PostgreSQL >= 9 required." : "Необхідно PostgreSQL >= 9.",
    "Please upgrade your database version." : "Оновіть версію бази даних.",
    "Your data directory is readable by other users." : "Ваш каталог даних доступний для читання іншим користувачам.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Змініть права доступу на 0770, щоб інші користувачі не могли отримати список файлів цього каталогу."
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
